@@ -21,10 +21,11 @@ public class PodmanApiCodegen extends DefaultCodegenConfig {
     {
       put("InlineResponse2001", "DockerImageBuildResponse");
       put("InlineResponse2003", "LibpodPodTopResponse");
+      put("InlineResponse2008", "LibpodImageSearchResponse");
       put("InlineResponse2009", "LibpodImageBuildResponse");
       put("InlineResponse20010", "LibpodContainerHealthcheckResponse");
       put("InlineResponse20011", "LibpodContainerInspectResponse");
-      put("InlineResponse20012", "LibpodContainerStatsResponse");
+      put("InlineResponse20012", "LibpodContainerStats");
       put("InlineResponse20013", "LibpodImageInspectResponse");
       put("InlineResponse20014", "LibpodImageTreeResponse");
       put("InlineResponse20015", "LibpodPodInspectResponse");
@@ -56,7 +57,7 @@ public class PodmanApiCodegen extends DefaultCodegenConfig {
   public PodmanApiCodegen() {
     super();
 
-    additionalProperties.put(CodegenConstants.PACKAGE_VERSION, "0.1.0");
+    additionalProperties.put(CodegenConstants.PACKAGE_VERSION, "0.2.0");
     additionalProperties.put(CodegenConstants.PACKAGE_NAME, "podman-api-stubs");
 
     /**
