@@ -648,13 +648,13 @@ impl ImagePushOptsBuilder {
         tls_verify => "tlsVerify"
     );
 
-    pub fn auth(&mut self, auth: RegistryAuth) -> &mut Self {
+    pub fn auth(mut self, auth: RegistryAuth) -> Self {
         self.auth = Some(auth);
         self
     }
 
-    pub fn build(self) -> PullOpts {
-        PullOpts {
+    pub fn build(self) -> ImagePushOpts {
+        ImagePushOpts {
             auth: self.auth,
             params: self.params,
         }
